#ifndef _ELM_ENTRY_INTERNAL_PART_EO_H_
#define _ELM_ENTRY_INTERNAL_PART_EO_H_

#ifndef _ELM_ENTRY_INTERNAL_PART_EO_CLASS_TYPE
#define _ELM_ENTRY_INTERNAL_PART_EO_CLASS_TYPE

typedef Eo Elm_Entry_Internal_Part;

#endif

#ifndef _ELM_ENTRY_INTERNAL_PART_EO_TYPES
#define _ELM_ENTRY_INTERNAL_PART_EO_TYPES


#endif
/** Elementary entry internal part class
 *
 * @ingroup Elm_Entry_Internal_Part
 */
#define ELM_ENTRY_INTERNAL_PART_CLASS elm_entry_internal_part_class_get()

EWAPI const Efl_Class *elm_entry_internal_part_class_get(void);

#endif
